package sun.security.timestamp;

import java.io.IOException;
import sun.security.util.ObjectIdentifier;
import sun.security.util.DerOutputStream;
import java.security.NoSuchAlgorithmException;
import java.security.MessageDigest;
import java.security.cert.X509Extension;
import java.math.BigInteger;
import sun.security.x509.AlgorithmId;

public class TSRequest
{
    private int version;
    private AlgorithmId hashAlgorithmId;
    private byte[] hashValue;
    private String policyId;
    private BigInteger nonce;
    private boolean returnCertificate;
    private X509Extension[] extensions;
    
    public TSRequest(String policyId, byte[] input, MessageDigest messageDigest) throws NoSuchAlgorithmException {
        this.version = 1;
        this.hashAlgorithmId = null;
        this.policyId = null;
        this.nonce = null;
        this.returnCertificate = false;
        this.extensions = null;
        this.policyId = policyId;
        this.hashAlgorithmId = AlgorithmId.get(messageDigest.getAlgorithm());
        this.hashValue = messageDigest.digest(input);
    }
    
    public byte[] getHashedMessage() {
        return (byte[])this.hashValue.clone();
    }
    
    public void setVersion(int version) {
        this.version = version;
    }
    
    public void setPolicyId(String policyId) {
        this.policyId = policyId;
    }
    
    public void setNonce(BigInteger nonce) {
        this.nonce = nonce;
    }
    
    public void requestCertificate(boolean returnCertificate) {
        this.returnCertificate = returnCertificate;
    }
    
    public void setExtensions(X509Extension[] extensions) {
        this.extensions = extensions;
    }
    
    public byte[] encode() throws IOException {
        DerOutputStream derOutputStream = new DerOutputStream();
        derOutputStream.putInteger(this.version);
        DerOutputStream out = new DerOutputStream();
        this.hashAlgorithmId.encode(out);
        out.putOctetString(this.hashValue);
        derOutputStream.write((byte)48, out);
        if (this.policyId != null) {
            derOutputStream.putOID(new ObjectIdentifier(this.policyId));
        }
        if (this.nonce != null) {
            derOutputStream.putInteger(this.nonce);
        }
        if (this.returnCertificate) {
            derOutputStream.putBoolean(true);
        }
        DerOutputStream derOutputStream2 = new DerOutputStream();
        derOutputStream2.write((byte)48, derOutputStream);
        return derOutputStream2.toByteArray();
    }
}
